===============================
Handle CMIP6
===============================

.. image:: https://img.shields.io/travis/TaufiqHassan/cmpdata.svg
        :target: https://travis-ci.org/TaufiqHassan/cmpdata

.. image:: https://img.shields.io/pypi/v/cmpdata.svg
        :target: https://pypi.python.org/pypi/cmpdata


``cmpdata`` package can handle and analyze raw CMIP6 data.

* GitHub repo: https://github.com/TaufiqHassan/cmpdata
* Documentation: 

Features
--------


License
-------

This code is licensed under the `MIT License`_.

.. _`MIT License`: https://opensource.org/licenses/MIT
